@@ -186,7 +186,7 @@ class Spider(metaclass=SpiderMeta):
                 codes = kwargs.get('codes', [])
                 if (codes and resp.code in codes) or (not codes and 200 <= resp.code < 300):
                     try:
-                        doc = callback(resp, *args)
+                        doc = callback(resp, *args, **kwargs)
                         if isinstance(doc, types.CoroutineType):
                             doc = await doc
                         if self.checker is not None:
