@@ -20,6 +20,7 @@ import re
 import socket
 import threading
 import time
+import urllib.parse
 import uuid
 import zlib
 from concurrent.futures import ThreadPoolExecutor
@@ -302,11 +303,10 @@ class BaseRequest(metaclass=RequestMeta):
         else:
             kwargs.setdefault('allow_redirects', True)
 
-        if kwargs.get('json'):
+        if kwargs.pop('json', False):
             headers['content-type'] = 'application/json; charset=utf-8'
             if isinstance(kwargs['data'], dict):
                 kwargs['data'] = json.dumps(kwargs['data'], ensure_ascii=False).encode('utf-8')
-            kwargs.pop('json')
 
         if isinstance(kwargs['data'], dict):
             # headers['content-type'] = 'application/x-www-form-urlencoded'
@@ -335,10 +335,15 @@ class BaseRequest(metaclass=RequestMeta):
             url = urlunparse((ret.scheme, ret.netloc, ret.path, ret.params, urlencode(query, doseq=True), ret.fragment))
             kwargs.pop('params')
 
-        kwargs['headers'] = headers
-        kwargs['cookies'] = cookies
         if url.startswith('//'):
             url = 'http:' + url
+        if kwargs.pop('autoreferer', False):
+            ret = urllib.parse.urlparse(url)
+            headers.update({
+                'referer': f'{ret.scheme}://{ret.netloc}',
+            })
+        kwargs['headers'] = headers
+        kwargs['cookies'] = cookies
         return url, kwargs
 
     def _request(self, url, **kwargs):
